@@ -11,39 +11,6 @@
 #import <ApplicationServices/ApplicationServices.h>
 #import <CoreGraphics/CoreGraphics.h>
 
-#if PyObjC_BUILD_RELEASE >= 1008
-
-typedef size_t (*CGDataProviderGetBytesCallback)(void* info, void* buffer, size_t count);
-typedef void (*CGDataProviderSkipBytesCallback)(void* info, size_t count);
-typedef void (*CGDataProviderRewindCallback)(void* info);
-typedef void (*CGDataProviderReleaseInfoCallback)(void* info);
-typedef const void* (*CGDataProviderGetBytePointerCallback)(void* info);
-typedef void (*CGDataProviderReleaseBytePointerCallback)(void* info, const void* pointer);
-typedef size_t (*CGDataProviderGetBytesAtOffsetCallback)(void* info, void* buffer,
-                                                         size_t offset, size_t count);
-
-typedef struct CGDataProviderCallbacks {
-    CGDataProviderGetBytesCallback    getBytes;
-    CGDataProviderSkipBytesCallback   skipBytes;
-    CGDataProviderRewindCallback      rewind;
-    CGDataProviderReleaseInfoCallback releaseProvider;
-} CGDataProviderCallbacks;
-
-typedef struct CGDataProviderDirectAccessCallbacks {
-    CGDataProviderGetBytePointerCallback     getBytePointer;
-    CGDataProviderReleaseBytePointerCallback releaseBytePointer;
-    CGDataProviderGetBytesAtOffsetCallback   getBytes;
-    CGDataProviderReleaseInfoCallback        releaseProvider;
-} CGDataProviderDirectAccessCallbacks;
-
-extern CGDataProviderRef CGDataProviderCreate(void*                          info,
-                                              const CGDataProviderCallbacks* callbacks);
-extern CGDataProviderRef
-CGDataProviderCreateDirectAccess(void* info, size_t size,
-                                 const CGDataProviderDirectAccessCallbacks* callbacks);
-
-#endif
-
 /*
  *
  * CGDataConsumerCreate
@@ -58,10 +25,9 @@ m_CGDataConsumerPutBytesCallback(void* _info, const void* buffer, size_t count)
 
     PyGILState_STATE state = PyGILState_Ensure();
 
-    PyObject* result = PyObject_CallFunction(PyTuple_GetItem(info, 0),
-                                             "Oy#l",
-                                             PyTuple_GetItem(info, 2), buffer,
-                                             (Py_ssize_t)count, (Py_ssize_t)count);
+    PyObject* result =
+        PyObject_CallFunction(PyTuple_GetItem(info, 0), "Oy#l", PyTuple_GetItem(info, 2),
+                              buffer, (Py_ssize_t)count, (Py_ssize_t)count);
     if (result == NULL) {
         PyObjCErr_ToObjCWithGILState(&state);
     }
@@ -209,7 +175,8 @@ m_CGDataProviderGetBytesCallback(void* _info, void* buffer, size_t count)
     if (PyTuple_GetItem(result, 1) != buf) {
         Py_buffer view;
 
-        if (PyObject_GetBuffer(PyTuple_GetItem(result, 1), &view, PyBUF_CONTIG_RO) == -1) {
+        if (PyObject_GetBuffer(PyTuple_GetItem(result, 1), &view, PyBUF_CONTIG_RO)
+            == -1) {
             Py_DECREF(result);
             Py_DECREF(buf);
             PyObjCErr_ToObjCWithGILState(&state);
@@ -237,25 +204,6 @@ m_CGDataProviderGetBytesCallback(void* _info, void* buffer, size_t count)
     return c_result;
 }
 
-static void
-m_CGDataProviderSkipBytesCallback(void* _info, size_t count)
-{
-    PyObject* info = (PyObject*)_info;
-
-    PyGILState_STATE state = PyGILState_Ensure();
-
-    if (PyTuple_GetItem(info, 2) != Py_None) {
-        PyObject* result = PyObject_CallFunction(PyTuple_GetItem(info, 2), "Ol",
-                                                 PyTuple_GetItem(info, 0), count);
-        if (result == NULL) {
-            PyObjCErr_ToObjCWithGILState(&state);
-        }
-        Py_DECREF(result);
-    }
-
-    PyGILState_Release(state);
-}
-
 static void
 m_CGDataProviderRewindCallback(void* _info)
 {
@@ -297,131 +245,6 @@ m_CGDataProviderReleaseInfoCallback(void* _info)
     PyGILState_Release(state);
 }
 
-static CGDataProviderCallbacks m_CGDataProviderCallbacks = {
-    m_CGDataProviderGetBytesCallback,   /* getBytes */
-    m_CGDataProviderSkipBytesCallback,  /* skipBytes */
-    m_CGDataProviderRewindCallback,     /* rewind */
-    m_CGDataProviderReleaseInfoCallback /* releaseProvider */
-};
-
-static const void*
-m_CGDataProviderGetBytePointerCallback(void* _info)
-{
-    PyObject* info = (PyObject*)_info;
-    void* buf;
-
-    PyGILState_STATE state = PyGILState_Ensure();
-
-    PyObject* result =
-        PyObject_CallFunction(PyTuple_GetItem(info, 1), "O", PyTuple_GetItem(info, 0));
-    if (result == NULL) {
-        PyObjCErr_ToObjCWithGILState(&state);
-    }
-    if (result == PyObjC_NULL || result == Py_None) {
-        Py_DECREF(result);
-        PyGILState_Release(state);
-        return NULL;
-    }
-
-    Py_buffer view;
-
-    if (PyObject_GetBuffer(PyTuple_GetItem(result, 1), &view, PyBUF_CONTIG_RO) == -1) {
-        Py_DECREF(result);
-        PyObjCErr_ToObjCWithGILState(&state);
-    }
-
-    /* XXX: This is unsafe, but there's no good way to keep the buffer alive long enough... */
-    buf = view.buf;
-    PyBuffer_Release(&view);
-
-    PyGILState_Release(state);
-    return buf;
-}
-
-static void
-m_CGDataProviderReleaseBytePointerCallback(void* _info, const void* pointer)
-{
-    /* FIXME: have to store enough info to recover the right PyObject* */
-}
-
-static size_t
-m_CGDataProviderGetBytesAtOffsetCallback(void* _info, void* buffer, size_t offset,
-                                         size_t count)
-{
-    PyObject* info = (PyObject*)_info;
-    PyObject* buf;
-
-    PyGILState_STATE state = PyGILState_Ensure();
-
-    Py_buffer view;
-    if (PyBuffer_FillInfo(&view, NULL, buffer, count, 0, PyBUF_WRITABLE) < 0) {
-        PyObjCErr_ToObjCWithGILState(&state);
-    }
-    buf = PyMemoryView_FromBuffer(&view);
-    if (buf == NULL) {
-        PyObjCErr_ToObjCWithGILState(&state);
-    }
-
-    PyObject* result = PyObject_CallFunction(
-        PyTuple_GetItem(info, 3), "OOll", PyTuple_GetItem(info, 0), buf, offset, count);
-    if (result == NULL) {
-        Py_DECREF(buf);
-        PyObjCErr_ToObjCWithGILState(&state);
-    }
-
-    if (!PyTuple_Check(result) || PyTuple_GET_SIZE(result) != 2) {
-        PyErr_Format(PyExc_TypeError, "Expecting result of type tuple of 2, got %s",
-                     result->ob_type->tp_name);
-        Py_DECREF(result);
-        Py_DECREF(buf);
-        PyObjCErr_ToObjCWithGILState(&state);
-    }
-
-    size_t c_result;
-    if (PyObjC_PythonToObjC(@encode(size_t), PyTuple_GetItem(result, 0), &c_result) < 0) {
-        Py_DECREF(result);
-        Py_DECREF(buf);
-        PyObjCErr_ToObjCWithGILState(&state);
-    }
-
-    if (PyTuple_GetItem(result, 1) != buf) {
-        Py_buffer view;
-
-        if (PyObject_GetBuffer(PyTuple_GetItem(result, 1), &view, PyBUF_CONTIG_RO) == -1) {
-            Py_DECREF(result);
-            Py_DECREF(buf);
-            PyObjCErr_ToObjCWithGILState(&state);
-        }
-
-        if ((size_t)view.len < c_result || (size_t)view.len > count) {
-            PyErr_SetString(PyExc_ValueError, "Inconsistent size");
-            PyBuffer_Release(&view);
-            Py_DECREF(result);
-            Py_DECREF(buf);
-            PyObjCErr_ToObjCWithGILState(&state);
-        }
-        memcpy(buffer, view.buf, c_result);
-        PyBuffer_Release(&view);
-    } else {
-        /* Assume that the user knows what he's doing and has
-         * filled the right bit of the buffer.
-         */
-    }
-
-    Py_DECREF(buf);
-    Py_DECREF(result);
-
-    PyGILState_Release(state);
-    return c_result;
-}
-
-static CGDataProviderDirectAccessCallbacks m_CGDataProviderDirectAccessCallbacks = {
-    m_CGDataProviderGetBytePointerCallback,     /* getBytePointer */
-    m_CGDataProviderReleaseBytePointerCallback, /* releaseBytePointer */
-    m_CGDataProviderGetBytesAtOffsetCallback,   /* getBytes */
-    m_CGDataProviderReleaseInfoCallback         /* releaseProvider */
-};
-
 static off_t
 m_CGDataProviderSkipForwardCallback(void* _info, off_t count)
 {
@@ -502,168 +325,8 @@ m_CGDataProviderCreateSequential(PyObject* self __attribute__((__unused__)),
     CGDataProviderRef result;
     Py_BEGIN_ALLOW_THREADS
         @try {
-            result = CGDataProviderCreateSequential(
-                real_info, &m_CGDataProviderSequentialCallbacks);
-
-        } @catch (NSException* localException) {
-            result = NULL;
-            PyObjCErr_FromObjC(localException);
-        }
-    Py_END_ALLOW_THREADS
-
-    if (result == NULL && PyErr_Occurred()) {
-        Py_DECREF(real_info);
-        return NULL;
-    }
-
-    if (result == NULL) {
-        Py_DECREF(real_info);
-        Py_INCREF(Py_None);
-        return Py_None;
-    }
-
-    PyObject* retval = PyObjC_ObjCToPython(@encode(CGDataProviderRef), &result);
-    /* CGDataProviderCreate donated a reference, we therefore now have
-     * one too many, release a reference.
-     */
-    CGDataProviderRelease(result);
-    return retval;
-}
-
-
-PyDoc_STRVAR(doc_CGDataProviderCreate, "CGDataConsumerCreate(info, (getBytes, skipBytes, "
-                                       "rewind, releaseProvider)) -> object\n"
-                                       "\n"
-                                       "getBytes, skipBytes, rewind and release are "
-                                       "callback functions. Release may be None");
-static PyObject*
-m_CGDataProviderCreate(PyObject* self __attribute__((__unused__)), PyObject* args)
-{
-    PyObject* info;
-    PyObject* getBytes;
-    PyObject* skipBytes;
-    PyObject* rewind;
-    PyObject* release;
-
-    if (!PyArg_ParseTuple(args, "O(OOOO)", &info, &getBytes, &skipBytes, &rewind,
-                          &release)) {
-        return NULL;
-    }
-
-    if (!PyCallable_Check(getBytes)) {
-        PyErr_SetString(PyExc_TypeError, "getBytes is not callable");
-        return NULL;
-    }
-    if (!PyCallable_Check(skipBytes)) {
-        PyErr_SetString(PyExc_TypeError, "skipBytes is not callable");
-        return NULL;
-    }
-    if (!PyCallable_Check(rewind)) {
-        PyErr_SetString(PyExc_TypeError, "rewind is not callable");
-        return NULL;
-    }
-    if (release != Py_None && !PyCallable_Check(release)) {
-        PyErr_SetString(PyExc_TypeError, "release is not callable");
-        return NULL;
-    }
-
-    PyObject* real_info =
-        Py_BuildValue("OOOOO", info, getBytes, skipBytes, rewind, release);
-    if (real_info == NULL) {
-        return NULL;
-    }
-
-    CGDataProviderRef result;
-    Py_BEGIN_ALLOW_THREADS
-        @try {
-            result = CGDataProviderCreate(real_info, &m_CGDataProviderCallbacks);
-
-        } @catch (NSException* localException) {
-            result = NULL;
-            PyObjCErr_FromObjC(localException);
-        }
-    Py_END_ALLOW_THREADS
-
-    if (result == NULL && PyErr_Occurred()) {
-        Py_DECREF(real_info);
-        return NULL;
-    }
-
-    if (result == NULL) {
-        Py_DECREF(real_info);
-        Py_INCREF(Py_None);
-        return Py_None;
-    }
-
-    PyObject* retval = PyObjC_ObjCToPython(@encode(CGDataProviderRef), &result);
-    /* CGDataProviderCreate donated a reference, we therefore now have
-     * one too many, release a reference.
-     */
-    CGDataProviderRelease(result);
-    return retval;
-}
-
-PyDoc_STRVAR(doc_CGDataProviderCreateDirectAccess,
-             "CGDataConsumerCreateDirectAccess(info, (getBytePointer, "
-             "releaseBytePointer, getBytes, release)) -> object\n"
-             "\n"
-             "getBytePointer, releaseBytePointer, getBytes and release are callback "
-             "functions. Release may be None");
-static PyObject*
-m_CGDataProviderCreateDirectAccess(PyObject* self __attribute__((__unused__)),
-                                   PyObject* args)
-{
-    PyObject* info;
-    PyObject* getBytePointer;
-    PyObject* releaseBytePointer;
-    PyObject* getBytes;
-    PyObject* release;
-    long      size;
-
-    CGDataProviderDirectAccessCallbacks callbacks = m_CGDataProviderDirectAccessCallbacks;
-
-    if (!PyArg_ParseTuple(args, "Ol(OOOO)", &info, &size, &getBytePointer,
-                          &releaseBytePointer, &getBytes, &release)) {
-        return NULL;
-    }
-
-    if (getBytePointer == Py_None) {
-        callbacks.getBytePointer = NULL;
-    } else if (!PyCallable_Check(getBytePointer)) {
-        PyErr_SetString(PyExc_TypeError, "getBytePointer is not callable");
-        return NULL;
-    }
-
-    if (releaseBytePointer == Py_None) {
-        callbacks.releaseBytePointer = NULL;
-    } else if (!PyCallable_Check(releaseBytePointer)) {
-        PyErr_SetString(PyExc_TypeError, "releaseBytePointer is not callable");
-        return NULL;
-    }
-
-    if (getBytes == Py_None) {
-        callbacks.getBytes = NULL;
-
-    } else if (!PyCallable_Check(getBytes)) {
-        PyErr_SetString(PyExc_TypeError, "getBytes is not callable");
-        return NULL;
-    }
-
-    if (release != Py_None && !PyCallable_Check(release)) {
-        PyErr_SetString(PyExc_TypeError, "release is not callable");
-        return NULL;
-    }
-
-    PyObject* real_info = Py_BuildValue("OOOOO", info, getBytePointer, releaseBytePointer,
-                                        getBytes, release);
-    if (real_info == NULL) {
-        return NULL;
-    }
-
-    CGDataProviderRef result;
-    Py_BEGIN_ALLOW_THREADS
-        @try {
-            result = CGDataProviderCreateDirectAccess(real_info, size, &callbacks);
+            result = CGDataProviderCreateSequential(real_info,
+                                                    &m_CGDataProviderSequentialCallbacks);
 
         } @catch (NSException* localException) {
             result = NULL;
@@ -703,7 +366,7 @@ m_releaseData(void* _info, const void* data, size_t size)
 
     PyGILState_STATE state = PyGILState_Ensure();
 
-    tag = PyLong_AsLong(PyTuple_GetItem(info, 2));
+    tag  = PyLong_AsLong(PyTuple_GetItem(info, 2));
     view = PyTuple_GetItem(info, 3);
 
     if (PyTuple_GetItem(info, 1) != Py_None) {
@@ -745,7 +408,7 @@ m_CGDataProviderCreateWithData(PyObject* self __attribute__((__unused__)), PyObj
     int        tag;
     PyObject*  bufobj = NULL;
     PyObject*  view;
-    Py_ssize_t sz     = (Py_ssize_t)size;
+    Py_ssize_t sz = (Py_ssize_t)size;
     void*      arr;
 
     view = PyObjCMemView_New();
@@ -753,7 +416,8 @@ m_CGDataProviderCreateWithData(PyObject* self __attribute__((__unused__)), PyObj
         return NULL;
     }
 
-    tag = PyObjC_PythonToCArray(NO, YES, @encode(char), data, &arr, &sz, &bufobj, PyObjCMemView_GetBuffer(view));
+    tag = PyObjC_PythonToCArray(NO, YES, @encode(char), data, &arr, &sz, &bufobj,
+                                PyObjCMemView_GetBuffer(view));
     if (tag < 0) {
         return NULL;
     }
@@ -801,7 +465,7 @@ m_CGFunctionEvaluateCallback(void* _info, const CGFloat* inData, CGFloat* outDat
 
     PyGILState_STATE state = PyGILState_Ensure();
 
-    domdim = PyLong_AsLong(PyTuple_GetItem(info, 2));
+    domdim   = PyLong_AsLong(PyTuple_GetItem(info, 2));
     rangedim = PyLong_AsLong(PyTuple_GetItem(info, 3));
 
     PyObject* input;
@@ -865,7 +529,7 @@ m_CGFunctionCreate(PyObject* self __attribute__((__unused__)), PyObject* args)
     CGFunctionRef result    = NULL;
     PyObject*     domainBuf = NULL;
     Py_buffer     domainView;
-    PyObject*     rangeBuf  = NULL;
+    PyObject*     rangeBuf = NULL;
     Py_buffer     rangeView;
     int           rangeTag;
     int           domainTag;
@@ -889,8 +553,9 @@ m_CGFunctionCreate(PyObject* self __attribute__((__unused__)), PyObject* args)
     } else {
         /* Parse Array */
         Py_ssize_t cnt = domainDimension * 2;
-        domainTag      = PyObjC_PythonToCArray(NO, NO, @encode(CGFloat), domain,
-                                          (void**)&domainArr, &cnt, &domainBuf, &domainView);
+        domainTag =
+            PyObjC_PythonToCArray(NO, NO, @encode(CGFloat), domain, (void**)&domainArr,
+                                  &cnt, &domainBuf, &domainView);
         if (domainTag < 0) {
             return NULL;
         }
@@ -1935,12 +1600,6 @@ static PyMethodDef mod_methods[] = {
     {"CGDataConsumerCreate", (PyCFunction)m_CGDataConsumerCreate, METH_VARARGS,
      doc_CGDataConsumerCreate},
 
-    {"CGDataProviderCreate", (PyCFunction)m_CGDataProviderCreate, METH_VARARGS,
-     doc_CGDataProviderCreate},
-
-    {"CGDataProviderCreateDirectAccess", (PyCFunction)m_CGDataProviderCreateDirectAccess,
-     METH_VARARGS, doc_CGDataProviderCreateDirectAccess},
-
 #if PyObjC_BUILD_RELEASE >= 1005
 
     {"CGDataProviderCreateSequential", (PyCFunction)m_CGDataProviderCreateSequential,
@@ -1976,15 +1635,7 @@ static PyMethodDef mod_methods[] = {
     }};
 
 static struct PyModuleDef mod_module = {
-     PyModuleDef_HEAD_INIT,
-     "_callbacks",
-     NULL,
-     0,
-     mod_methods,
-     NULL,
-     NULL,
-     NULL,
-     NULL};
+    PyModuleDef_HEAD_INIT, "_callbacks", NULL, 0, mod_methods, NULL, NULL, NULL, NULL};
 
 PyObject* PyInit__callbacks(void);
 
